@@ -50,11 +50,12 @@ Support: https://github.com/digitalec/sonus"""
 @click.argument('ODM', metavar='PATH', nargs=-1)
 @click.option('-i', '--info', is_flag=True, help="Show info of ODM file", hidden=True)
 @click.option('-d', '--download', is_flag=True, help="Download book only, do not chapterize")
+@click.option('-g', '--generic', is_flag=True, help="Use generic chapter names (Chapter 1, Chapter 2, etc.)")
 @click.option('-r', '--return', 'return_book', is_flag=True, help="Return an audiobook")
 @click.option('-o', '--output', 'output_path', type=str, help="Output directory")
 @click.option('-v', '--verbose', is_flag=True, help="Show verbose output")
 @click.version_option(__VERSION__, '--version', '-V', 'version', message=version_info())
-def main(odm, info, download, return_book, output_path, verbose):
+def main(odm, info, download, generic, return_book, output_path, verbose):
     """sonus is an OverDrive download manager and chapterizer for audiobooks
     
     You can download and chapterize a book by simply passing the ODM file
@@ -88,7 +89,7 @@ def main(odm, info, download, return_book, output_path, verbose):
         logger.debug(f"Input file: {str(arg)}")
         
         if Path(arg).is_dir():
-            chapterizer.main(arg, output_path)
+            chapterizer.main(arg, output_path, generic)
             continue
 
         elif Path(arg).is_file() and Path(arg).suffix == ".odm":
@@ -108,7 +109,7 @@ def main(odm, info, download, return_book, output_path, verbose):
             tmpdir = tempfile.TemporaryDirectory()
             logger.debug(f"Downloading parts to temporary directory: {tmpdir.name}")
             get_book(arg, tmpdir.name)
-            chapterizer.main(tmpdir.name, output_path)
+            chapterizer.main(tmpdir.name, output_path, generic)
             tmpdir.cleanup()
 
 
